.. _bfg_wiki_tutorial:

ZODB + Traversal Wiki Tutorial
==============================

This tutorial introduces a :term:`traversal` -based :app:`Pyramid`
application to a developer familiar with Python.  It will be most familiar to
developers with previous :term:`Zope` experience.  When we're done with the
tutorial, the developer will have created a basic Wiki application with
authentication.

For cut and paste purposes, the source code for all stages of this
tutorial can be browsed at
`http://github.com/Pylons/pyramid/tree/1.2-branch/docs/tutorials/wiki/src/
<http://github.com/Pylons/pyramid/tree/1.2-branch/docs/tutorials/wiki/src/>`_.

.. toctree::
   :maxdepth: 2

   background
   installation
   basiclayout
   definingmodels
   definingviews
   authorization
   tests
   distributing

